==> merchantapi-2.4.0-py3-none-any.whl: merchantapi/model/product_attribute_list_option.py <==
"""
This file is part of the MerchantAPI package.

(c) Miva Inc <https://www.miva.com/>

For the full copyright and license information, please view the LICENSE
file that was distributed with this source code.

ProductAttributeListOption data model.
"""

from merchantapi.abstract import Model

class ProductAttributeListOption(Model):
	def __init__(self, data: dict = None):
		"""
		ProductAttributeListOption Constructor

		:param data: dict
		"""

		super().__init__(data)

	def get_id(self) -> int:
		"""
		Get id.

		:returns: int
		"""

		return self.get_field('id', 0)

	def get_product_id(self) -> int:
		"""
		Get product_id.

		:returns: int
		"""

		return self.get_field('product_id', 0)

	def get_attribute_id(self) -> int:
		"""
		Get attr_id.

		:returns: int
		"""

		return self.get_field('attr_id', 0)

	def get_attribute_template_id(self) -> int:
		"""
		Get attemp_id.

		:returns: int
		"""

		return self.get_field('attemp_id', 0)

	def get_attribute_template_attribute_id(self) -> int:
		"""
		Get attmpat_id.

		:returns: int
		"""

		return self.get_field('attmpat_id', 0)

	def get_display_order(self) -> int:
		"""
		Get disp_order.

		:returns: int
		"""

		if self.has_field('disp_order'):
			return self.get_field('disp_order', 0)
		elif self.has_field('disporder'):
			return self.get_field('disporder', 0)

		return 0

	def get_code(self) -> str:
		"""
		Get code.

		:returns: string
		"""

		return self.get_field('code')

	def get_prompt(self) -> str:
		"""
		Get prompt.

		:returns: string
		"""

		return self.get_field('prompt')

	def get_price(self) -> float:
		"""
		Get price.

		:returns: float
		"""

		return self.get_field('price', 0.00)

	def get_cost(self) -> float:
		"""
		Get cost.

		:returns: float
		"""

		return self.get_field('cost', 0.00)

	def get_weight(self) -> float:
		"""
		Get weight.

		:returns: float
		"""

		return self.get_field('weight', 0.00)

	def get_image(self) -> str:
		"""
		Get image.

		:returns: string
		"""

		return self.get_field('image')

	def get_default_option(self) -> bool:
		"""
		Get default_opt.

		:returns: bool
		"""

		return self.get_field('default_opt', False)

	def get_has_variant_parts(self) -> bool:
		"""
		Get has_variant_parts.

		:returns: bool
		"""

		return self.get_field('has_variant_parts', False)

==> merchantapi-2.7.0-py3-none-any.whl: merchantapi/model/product_attribute_list_option.py <==
"""
This file is part of the MerchantAPI package.

(c) Miva Inc <https://www.miva.com/>

For the full copyright and license information, please view the LICENSE
file that was distributed with this source code.

ProductAttributeListOption data model.
"""

from merchantapi.abstract import Model
from decimal import Decimal

class ProductAttributeListOption(Model):
	def __init__(self, data: dict = None):
		"""
		ProductAttributeListOption Constructor

		:param data: dict
		"""

		super().__init__(data)

		if 'price' in self: self['price'] = Decimal(self['price'])
		if 'cost' in self: self['cost'] = Decimal(self['cost'])
		if 'weight' in self: self['weight'] = Decimal(self['weight'])

	def get_id(self) -> int:
		"""
		Get id.

		:returns: int
		"""

		return self.get_field('id', 0)

	def get_product_id(self) -> int:
		"""
		Get product_id.

		:returns: int
		"""

		return self.get_field('product_id', 0)

	def get_attribute_id(self) -> int:
		"""
		Get attr_id.

		:returns: int
		"""

		return self.get_field('attr_id', 0)

	def get_attribute_template_id(self) -> int:
		"""
		Get attemp_id.

		:returns: int
		"""

		return self.get_field('attemp_id', 0)

	def get_attribute_template_attribute_id(self) -> int:
		"""
		Get attmpat_id.

		:returns: int
		"""

		return self.get_field('attmpat_id', 0)

	def get_display_order(self) -> int:
		"""
		Get disp_order.

		:returns: int
		"""

		if self.has_field('disp_order'):
			return self.get_field('disp_order', 0)
		elif self.has_field('disporder'):
			return self.get_field('disporder', 0)

		return 0

	def get_code(self) -> str:
		"""
		Get code.

		:returns: string
		"""

		return self.get_field('code')

	def get_prompt(self) -> str:
		"""
		Get prompt.

		:returns: string
		"""

		return self.get_field('prompt')

	def get_price(self) -> Decimal:
		"""
		Get price.

		:returns: Decimal
		"""

		return self.get_field('price', Decimal(0.00))

	def get_cost(self) -> Decimal:
		"""
		Get cost.

		:returns: Decimal
		"""

		return self.get_field('cost', Decimal(0.00))

	def get_weight(self) -> Decimal:
		"""
		Get weight.

		:returns: Decimal
		"""

		return self.get_field('weight', Decimal(0.00))

	def get_image(self) -> str:
		"""
		Get image.

		:returns: string
		"""

		return self.get_field('image')

	def get_default_option(self) -> bool:
		"""
		Get default_opt.

		:returns: bool
		"""

		return self.get_field('default_opt', False)

	def get_has_variant_parts(self) -> bool:
		"""
		Get has_variant_parts.

		:returns: bool
		"""

		return self.get_field('has_variant_parts', False)
